Changelog
=========


2.0.0 (2021-06-20)
------------------

BREAKING CHANGE
~~~~~~~~~~~~~~~
- Rename method, catch exceptions when check and format value. [qin_hw]


1.0.1 (2021-06-20)
------------------

Bug Fixes
~~~~~~~~~
- Raise exception when set init value to none. [qin_hw]


1.0.0 (2021-06-19)
------------------

Features
~~~~~~~~
- Support multi-level nested key. [qin_hw]
- Remove api of attribute. [qin_hw]
- Add class attribute. [qin_hw]
- Implement yaml config manager. [qin_hw]

BREAKING CHANGE
~~~~~~~~~~~~~~~
- Update project url. [qin_hw]
- Rename package name from yamlconf --> ymlconf. [qin_hw]
- Rename package name from yamlconf --> ymlconf. [qin_hw]


0.1.0 (2021-06-19)
------------------

* First commit.
